#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : send_email
# @Time         : 2020-03-04 13:58
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import smtplib
from email.mime.text import MIMEText
from email.header import Header


def send_email(subject="邮件测试", msg="邮件测试信息", receivers='yuanjie@xiaomi.com', isstaging=1, _subtype='html'):
    token = {
        "mail.b2c.srv": "U92BzW2jqR@xiaomi.com",
        "mail.test.b2c.srv": "134a1ab8c0efbe14884b9956321818e0@xiaomi.com"
        # "9297367afe24f39009dae012d2fd0342@xiaomi.com"
    }
    smtp = smtplib.SMTP("mail.test.b2c.srv" if isstaging else "mail.b2c.srv", 25)
    sender = token[smtp._host]

    if isinstance(receivers, str) and receivers.__contains__("@"):
        receivers = [receivers]

    message = MIMEText(msg, _subtype, 'utf-8')
    message['Subject'] = Header(subject, 'utf-8')
    message['From'] = sender
    message['To'] = ",".join(receivers)

    try:
        smtp.sendmail(sender, receivers, message.as_string())
        print("邮件发送成功")
    except smtplib.SMTPException as e:
        print(f"{e}: 无法发送邮件")


if __name__ == '__main__':
    send_email(isstaging=1)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : __init__.py
# @Time         : 2020-03-04 13:31
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import os
import pandas as pd
from pyhive import hive
from twisted.conch.scripts.conch import conn

__all__ = ['kinit', 'hive_conn']


def kinit(keytab="/fds/data/h_browser.keytab"):
    cmd = f"kinit -k -t {keytab} h_browser@XIAOMI.HADOOP && klist"
    _ = os.popen(cmd).read()
    print(_)


def hive_conn(keytab="/fds/data/h_browser.keytab"):
    """
    conn = hive_conn()
    sql='select count(1) from browser.mipush_browser_label'
    def get_df(sql):
        df = pd.read_sql(sql, conn)
        df.columns = [col.split('.')[1] if '.' in col else col for col in df.columns]
        return df

    """

    kinit(keytab)

    conn = hive.connect(
        host="zjyprc-hadoop.hive.srv", port=10000,
        auth="KERBEROS", kerberos_service_name="sql_prc",
        configuration={
            'mapreduce.map.memory.mb': '10240',
            'mapreduce.reduce.memory.mb': '10240',
            'mapreduce.map.java.opts': '-Xmx3072m',
            'mapreduce.reduce.java.opts': '-Xmx3072m',
            'hive.input.format': 'org.apache.hadoop.hive.ql.io.HiveInputFormat',
            'hive.limit.optimize.enable': 'false',
            'mapreduce.job.queuename': 'root.production.miui_group.browser.miui_browser_zjy_1',  # zjy
        },
    )
    return conn



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : test
# @Time         : 2020-03-11 14:56
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from mi.app.zk_app import app

if __name__ == '__main__':
    import os
    import socket

    me = socket.gethostname() == 'yuanjie-Mac.local'

    uvicorn = "uvicorn" if me else "/opt/soft/python3/bin/uvicorn"

    main_file = __file__.split('/')[-1].split('.')[0]

    # --reload测试环境
    os.system(f"uvicorn {main_file}:app --reload --host 0.0.0.0 --port 8000")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : xiaomi
# @Time         : 2020-03-03 19:19
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : https://github.com/XiaoMi/galaxy-fds-sdk-python

# galaxy-fds-sdk
from fds import GalaxyFDSClient, GalaxyFDSClientException, FDSClientConfiguration

config = FDSClientConfiguration(
    endpoint="cnbj1.fds.api.xiaomi.com",
    enable_cdn_for_upload=False,
    enable_cdn_for_download=False,
)
client = GalaxyFDSClient(
    access_key="AKYPIJU65VF5BW6HNW",
    access_secret="pZKCf0leb+dywTnN5WVxkueST+rq24wPSgS/9FqU",
    config=config
)

try:
    client.create_bucket("bucket-name-demo")
except GalaxyFDSClientException as e:
    print(e.message)

client.delete_bucket("bucket-name-demo")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : __init__.py
# @Time         : 2020-03-04 14:45
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import os
import re
from pathlib import Path
from .zk import Config

zk_cfg = Config.zk_cfg

dev = False if re.search('.c3_|.c4_', os.environ.get('DOCKER_JOBNAME', '')) else True
prd = Path('/home/work').exists()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : EmailApp
# @Time         : 2020-03-06 09:41
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import time
import pandas as pd
from typing import Optional
from fastapi import FastAPI, Form, Depends, File, UploadFile
from pydantic import BaseModel
from starlette.staticfiles import StaticFiles
from starlette.requests import Request
from starlette.responses import \
    RedirectResponse, FileResponse, HTMLResponse, PlainTextResponse
from starlette.status import *

ROUTE = ""
app = FastAPI(
    debug=True,
    openapi_url=f"{ROUTE}/openapi.json",
    docs_url=f"{ROUTE}/docs",
    redoc_url=f"{ROUTE}/redoc",
    swagger_ui_oauth2_redirect_url=f"{ROUTE}/docs/oauth2-redirect"
)


async def parse_my_form(request: Request) -> dict:
    form_data = await request.form()
    return dict(form_data)


@app.post("/my-form-endpoint")
async def my_endpoint(request: Request):
    form_data = await request.form()
    with open(f"{time.time()}.txt", 'w') as f:
        f.write(str(dict(form_data)))
    return "post succeed"


@app.get("/")
def read_root():
    return {"Hello": "World"}


@app.get("/report")
def read_root():
    # return HTMLResponse(content=open("/Users/yuanjie/Desktop/notebook/your_report.html").read())
    return PlainTextResponse(content=open("/Users/yuanjie/Desktop/notebook/your_report.html").read())


@app.get("/reports")
def read_root():
    print(1)
    return FileResponse(path="/Users/yuanjie/Desktop/notebook/your_report.html", filename='downloadName')


from fastapi.staticfiles import StaticFiles

app.mount("/static", StaticFiles(directory="static"), name="static")

# HTMLResponse(content="htmlString")
# HTMLResponse(content=open("/Users/yuanjie/Desktop/notebook/your_report.html").read())
# FileResponse(path="/Users/yuanjie/Desktop/notebook/your_report.html", filename=None) # 等价于上方
# FileResponse(path="./file.txt", filename='downloadName')
# https://fastapi.tiangolo.com/tutorial/background-tasks/

if __name__ == '__main__':
    import os
    import socket

    me = socket.gethostname() == 'yuanjie-Mac.local'

    uvicorn = "uvicorn" if me else "/opt/soft/python3/bin/uvicorn"

    main_file = __file__.split('/')[-1].split('.')[0]

    # --reload测试环境
    os.system(f"uvicorn {main_file}:app --reload --host 0.0.0.0 --port 8000")
